package org.acra.builder;

import android.app.Notification;
import android.app.NotificationManager;
import android.app.PendingIntent;
import android.content.Context;
import android.content.Intent;
import android.content.SharedPreferences;
import android.os.Debug;
import android.os.Looper;
import android.widget.Toast;
import androidx.core.app.g;
import java.io.File;
import java.lang.Thread;
import java.util.Date;
import org.acra.ACRA;
import org.acra.ACRAConstants;
import org.acra.ReportField;
import org.acra.ReportingInteractionMode;
import org.acra.collector.CrashReportData;
import org.acra.collector.CrashReportDataFactory;
import org.acra.config.ACRAConfiguration;
import org.acra.file.CrashReportPersister;
import org.acra.file.ReportLocator;
import org.acra.log.ACRALog;
import org.acra.prefs.SharedPreferencesFactory;
import org.acra.sender.SenderServiceStarter;
import org.acra.util.ProcessFinisher;
import org.acra.util.ToastSender;

public final class ReportExecutor {
    private static int mNotificationCounter;
    private final ACRAConfiguration config;
    private final Context context;
    private final CrashReportDataFactory crashReportDataFactory;
    private final Thread.UncaughtExceptionHandler defaultExceptionHandler;
    private boolean enabled = false;
    private final ProcessFinisher processFinisher;
    private final ReportPrimer reportPrimer;

    /* access modifiers changed from: private */
    public static class TimeHelper {
        private Long initialTimeMillis;

        private TimeHelper() {
        }

        public long getElapsedTime() {
            if (this.initialTimeMillis == null) {
                return 0;
            }
            return System.currentTimeMillis() - this.initialTimeMillis.longValue();
        }

        public void setInitialTimeMillis(long j) {
            this.initialTimeMillis = Long.valueOf(j);
        }
    }

    public ReportExecutor(Context context2, ACRAConfiguration aCRAConfiguration, CrashReportDataFactory crashReportDataFactory2, Thread.UncaughtExceptionHandler uncaughtExceptionHandler, ReportPrimer reportPrimer2, ProcessFinisher processFinisher2) {
        this.context = context2;
        this.config = aCRAConfiguration;
        this.crashReportDataFactory = crashReportDataFactory2;
        this.defaultExceptionHandler = uncaughtExceptionHandler;
        this.reportPrimer = reportPrimer2;
        this.processFinisher = processFinisher2;
    }

    private Intent createCrashReportDialogIntent(File file, ReportBuilder reportBuilder) {
        if (ACRA.DEV_LOGGING) {
            ACRALog aCRALog = ACRA.log;
            String str = ACRA.LOG_TAG;
            aCRALog.d(str, "Creating DialogIntent for " + file + " exception=" + reportBuilder.getException());
        }
        Intent intent = new Intent(this.context, this.config.reportDialogClass());
        intent.putExtra(ACRAConstants.EXTRA_REPORT_FILE, file);
        intent.putExtra(ACRAConstants.EXTRA_REPORT_EXCEPTION, reportBuilder.getException());
        intent.putExtra(ACRAConstants.EXTRA_REPORT_CONFIG, this.config);
        return intent;
    }

    private void createNotification(File file, ReportBuilder reportBuilder) {
        NotificationManager notificationManager = (NotificationManager) this.context.getSystemService("notification");
        int resNotifIcon = this.config.resNotifIcon();
        CharSequence text = this.context.getText(this.config.resNotifTickerText());
        long currentTimeMillis = System.currentTimeMillis();
        if (ACRA.DEV_LOGGING) {
            ACRA.log.d(ACRA.LOG_TAG, "Creating Notification for " + file);
        }
        Intent createCrashReportDialogIntent = createCrashReportDialogIntent(file, reportBuilder);
        Context context2 = this.context;
        int i = mNotificationCounter;
        mNotificationCounter = i + 1;
        PendingIntent activity = PendingIntent.getActivity(context2, i, createCrashReportDialogIntent, 134217728);
        CharSequence text2 = this.context.getText(this.config.resNotifTitle());
        CharSequence text3 = this.context.getText(this.config.resNotifText());
        g.b bVar = new g.b(this.context);
        bVar.i(resNotifIcon);
        bVar.j(text);
        bVar.k(currentTimeMillis);
        bVar.d(true);
        bVar.g(text2);
        bVar.f(text3);
        bVar.e(activity);
        Notification a2 = bVar.a();
        a2.flags |= 16;
        Intent createCrashReportDialogIntent2 = createCrashReportDialogIntent(file, reportBuilder);
        createCrashReportDialogIntent2.putExtra(ACRAConstants.EXTRA_FORCE_CANCEL, true);
        a2.deleteIntent = PendingIntent.getActivity(this.context, -1, createCrashReportDialogIntent2, 0);
        notificationManager.notify(ACRAConstants.NOTIF_CRASH_ID, a2);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void dialogAndEnd(ReportBuilder reportBuilder, File file, boolean z) {
        if (z) {
            if (ACRA.DEV_LOGGING) {
                ACRALog aCRALog = ACRA.log;
                String str = ACRA.LOG_TAG;
                aCRALog.d(str, "Creating CrashReportDialog for " + file);
            }
            Intent createCrashReportDialogIntent = createCrashReportDialogIntent(file, reportBuilder);
            createCrashReportDialogIntent.setFlags(268435456);
            this.context.startActivity(createCrashReportDialogIntent);
        }
        if (ACRA.DEV_LOGGING) {
            ACRALog aCRALog2 = ACRA.log;
            String str2 = ACRA.LOG_TAG;
            aCRALog2.d(str2, "Wait for Toast + worker ended. Kill Application ? " + reportBuilder.isEndApplication());
        }
        if (!reportBuilder.isEndApplication()) {
            return;
        }
        if (Debug.isDebuggerConnected()) {
            new Thread() {
                /* class org.acra.builder.ReportExecutor.AnonymousClass3 */

                public void run() {
                    Looper.prepare();
                    Toast.makeText(ReportExecutor.this.context, "Warning: Acra may behave differently with a debugger attached", 1).show();
                    Looper.loop();
                }
            }.start();
            ACRA.log.w(ACRA.LOG_TAG, "Warning: Acra may behave differently with a debugger attached");
            this.processFinisher.finishLastActivity(reportBuilder.getUncaughtExceptionThread());
            return;
        }
        endApplication(reportBuilder.getUncaughtExceptionThread(), reportBuilder.getException());
    }

    private void endApplication(Thread thread, Throwable th) {
        boolean alsoReportToAndroidFramework = this.config.alsoReportToAndroidFramework();
        if (!(thread != null) || !alsoReportToAndroidFramework || this.defaultExceptionHandler == null) {
            this.processFinisher.endApplication(thread);
            return;
        }
        if (ACRA.DEV_LOGGING) {
            ACRA.log.d(ACRA.LOG_TAG, "Handing Exception on to default ExceptionHandler");
        }
        this.defaultExceptionHandler.uncaughtException(thread, th);
    }

    private File getReportFileName(CrashReportData crashReportData) {
        Object property = crashReportData.getProperty(ReportField.USER_CRASH_DATE);
        String property2 = crashReportData.getProperty(ReportField.IS_SILENT);
        StringBuilder sb = new StringBuilder();
        if (property == null) {
            property = Long.valueOf(new Date().getTime());
        }
        sb.append(property);
        sb.append(property2 != null ? ACRAConstants.SILENT_SUFFIX : "");
        sb.append(ACRAConstants.REPORTFILE_EXTENSION);
        return new File(new ReportLocator(this.context).getUnapprovedFolder(), sb.toString());
    }

    private void saveCrashReportFile(File file, CrashReportData crashReportData) {
        try {
            if (ACRA.DEV_LOGGING) {
                ACRALog aCRALog = ACRA.log;
                String str = ACRA.LOG_TAG;
                aCRALog.d(str, "Writing crash report file " + file);
            }
            new CrashReportPersister().store(crashReportData, file);
        } catch (Exception e2) {
            ACRA.log.e(ACRA.LOG_TAG, "An error occurred while writing the report file...", e2);
        }
    }

    private void startSendingReports(boolean z) {
        if (this.enabled) {
            new SenderServiceStarter(this.context, this.config).startService(z, true);
        } else {
            ACRA.log.w(ACRA.LOG_TAG, "Would be sending reports, but ACRA is disabled");
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:23:0x0051  */
    public void execute(final ReportBuilder reportBuilder) {
        boolean z;
        ReportingInteractionMode reportingInteractionMode;
        boolean z2;
        ReportingInteractionMode reportingInteractionMode2;
        if (!this.enabled) {
            ACRA.log.v(ACRA.LOG_TAG, "ACRA is disabled. Report not sent.");
            return;
        }
        this.reportPrimer.primeReport(this.context, reportBuilder);
        if (!reportBuilder.isSendSilently()) {
            reportingInteractionMode = this.config.mode();
        } else {
            reportingInteractionMode = ReportingInteractionMode.SILENT;
            if (this.config.mode() != reportingInteractionMode) {
                z = true;
                ReportingInteractionMode reportingInteractionMode3 = ReportingInteractionMode.TOAST;
                z2 = reportingInteractionMode != reportingInteractionMode3 || (this.config.resToastText() != 0 && (reportingInteractionMode == ReportingInteractionMode.NOTIFICATION || reportingInteractionMode == ReportingInteractionMode.DIALOG));
                final TimeHelper timeHelper = new TimeHelper();
                if (z2) {
                    new Thread() {
                        /* class org.acra.builder.ReportExecutor.AnonymousClass1 */

                        public void run() {
                            Looper.prepare();
                            ToastSender.sendToast(ReportExecutor.this.context, ReportExecutor.this.config.resToastText(), 1);
                            timeHelper.setInitialTimeMillis(System.currentTimeMillis());
                            Looper.loop();
                        }
                    }.start();
                }
                CrashReportData createCrashData = this.crashReportDataFactory.createCrashData(reportBuilder);
                final File reportFileName = getReportFileName(createCrashData);
                saveCrashReportFile(reportFileName, createCrashData);
                SharedPreferences create = new SharedPreferencesFactory(this.context, this.config).create();
                reportingInteractionMode2 = ReportingInteractionMode.SILENT;
                if (reportingInteractionMode != reportingInteractionMode2 || reportingInteractionMode == reportingInteractionMode3 || create.getBoolean(ACRA.PREF_ALWAYS_ACCEPT, false)) {
                    startSendingReports(z);
                    if (reportingInteractionMode == reportingInteractionMode2 && !reportBuilder.isEndApplication()) {
                    }
                } else if (reportingInteractionMode == ReportingInteractionMode.NOTIFICATION) {
                    if (ACRA.DEV_LOGGING) {
                        ACRA.log.d(ACRA.LOG_TAG, "Creating Notification.");
                    }
                    createNotification(reportFileName, reportBuilder);
                }
                final boolean z3 = reportingInteractionMode == ReportingInteractionMode.DIALOG && !create.getBoolean(ACRA.PREF_ALWAYS_ACCEPT, false);
                if (z2) {
                    new Thread() {
                        /* class org.acra.builder.ReportExecutor.AnonymousClass2 */

                        public void run() {
                            if (ACRA.DEV_LOGGING) {
                                ACRALog aCRALog = ACRA.log;
                                String str = ACRA.LOG_TAG;
                                aCRALog.d(str, "Waiting for 2000 millis from " + timeHelper.initialTimeMillis + " currentMillis=" + System.currentTimeMillis());
                            }
                            long elapsedTime = 2000 - timeHelper.getElapsedTime();
                            if (elapsedTime > 0) {
                                try {
                                    Thread.sleep(elapsedTime);
                                } catch (InterruptedException e2) {
                                    if (ACRA.DEV_LOGGING) {
                                        ACRA.log.d(ACRA.LOG_TAG, "Interrupted while waiting for Toast to end.", e2);
                                    }
                                }
                            }
                            if (ACRA.DEV_LOGGING) {
                                ACRA.log.d(ACRA.LOG_TAG, "Finished waiting for Toast");
                            }
                            ReportExecutor.this.dialogAndEnd(reportBuilder, reportFileName, z3);
                        }
                    }.start();
                    return;
                } else {
                    dialogAndEnd(reportBuilder, reportFileName, z3);
                    return;
                }
            }
        }
        z = false;
        ReportingInteractionMode reportingInteractionMode32 = ReportingInteractionMode.TOAST;
        if (reportingInteractionMode != reportingInteractionMode32) {
        }
        final TimeHelper timeHelper2 = new TimeHelper();
        if (z2) {
        }
        CrashReportData createCrashData2 = this.crashReportDataFactory.createCrashData(reportBuilder);
        final File reportFileName2 = getReportFileName(createCrashData2);
        saveCrashReportFile(reportFileName2, createCrashData2);
        SharedPreferences create2 = new SharedPreferencesFactory(this.context, this.config).create();
        reportingInteractionMode2 = ReportingInteractionMode.SILENT;
        if (reportingInteractionMode != reportingInteractionMode2) {
        }
        startSendingReports(z);
    }

    public void handReportToDefaultExceptionHandler(Thread thread, Throwable th) {
        if (this.defaultExceptionHandler != null) {
            ACRALog aCRALog = ACRA.log;
            String str = ACRA.LOG_TAG;
            aCRALog.i(str, "ACRA is disabled for " + this.context.getPackageName() + " - forwarding uncaught Exception on to default ExceptionHandler");
            this.defaultExceptionHandler.uncaughtException(thread, th);
            return;
        }
        ACRALog aCRALog2 = ACRA.log;
        String str2 = ACRA.LOG_TAG;
        aCRALog2.e(str2, "ACRA is disabled for " + this.context.getPackageName() + " - no default ExceptionHandler");
        ACRALog aCRALog3 = ACRA.log;
        aCRALog3.e(str2, "ACRA caught a " + th.getClass().getSimpleName() + " for " + this.context.getPackageName(), th);
    }

    public boolean isEnabled() {
        return this.enabled;
    }

    public void setEnabled(boolean z) {
        this.enabled = z;
    }
}
