package org.acra.collections;

import java.util.Collection;
import java.util.Iterator;
import java.util.LinkedList;

public final class BoundedLinkedList<E> extends LinkedList<E> {
    private final int maxSize;

    public BoundedLinkedList(int i) {
        this.maxSize = i;
    }

    @Override // java.util.AbstractCollection, java.util.List, java.util.Collection, java.util.AbstractList, java.util.Queue, java.util.LinkedList, java.util.Deque
    public boolean add(E e2) {
        if (size() == this.maxSize) {
            removeFirst();
        }
        return super.add(e2);
    }

    @Override // java.util.AbstractCollection, java.util.List, java.util.Collection, java.util.LinkedList
    public boolean addAll(Collection<? extends E> collection) {
        int size = collection.size();
        if (size > this.maxSize) {
            LinkedList linkedList = new LinkedList(collection);
            for (int i = 0; i < size - this.maxSize; i++) {
                linkedList.removeFirst();
            }
            collection = linkedList;
        }
        int size2 = (size() + collection.size()) - this.maxSize;
        if (size2 > 0) {
            removeRange(0, size2);
        }
        return super.addAll(collection);
    }

    @Override // java.util.LinkedList, java.util.Deque
    public void addFirst(E e2) {
        throw new UnsupportedOperationException();
    }

    @Override // java.util.LinkedList, java.util.Deque
    public void addLast(E e2) {
        add(e2);
    }

    @Override // java.util.Queue, java.util.LinkedList, java.util.Deque
    public boolean offer(E e2) {
        return add(e2);
    }

    @Override // java.util.LinkedList, java.util.Deque
    public boolean offerFirst(E e2) {
        addFirst(e2);
        return true;
    }

    @Override // java.util.LinkedList, java.util.Deque
    public boolean offerLast(E e2) {
        return add(e2);
    }

    @Override // java.util.LinkedList, java.util.Deque
    public void push(E e2) {
        add(e2);
    }

    public String toString() {
        StringBuilder sb = new StringBuilder();
        Iterator<E> it = iterator();
        while (it.hasNext()) {
            sb.append(it.next().toString());
        }
        return sb.toString();
    }

    @Override // java.util.List, java.util.AbstractList, java.util.LinkedList, java.util.AbstractSequentialList
    public void add(int i, E e2) {
        if (size() == this.maxSize) {
            removeFirst();
        }
        super.add(i, e2);
    }

    @Override // java.util.List, java.util.AbstractList, java.util.LinkedList, java.util.AbstractSequentialList
    public boolean addAll(int i, Collection<? extends E> collection) {
        if (i == size()) {
            return super.addAll(i, collection);
        }
        throw new UnsupportedOperationException();
    }
}
