package org.acra.collector;

import android.annotation.SuppressLint;
import android.content.Context;
import android.content.SharedPreferences;
import android.telephony.TelephonyManager;
import java.util.Set;
import org.acra.ACRA;
import org.acra.ACRAConstants;
import org.acra.ReportField;
import org.acra.builder.ReportBuilder;
import org.acra.log.ACRALog;
import org.acra.model.Element;
import org.acra.model.StringElement;
import org.acra.util.PackageManagerWrapper;

/* access modifiers changed from: package-private */
public final class DeviceIdCollector extends Collector {
    private final Context context;
    private final PackageManagerWrapper pm;
    private final SharedPreferences prefs;

    DeviceIdCollector(Context context2, PackageManagerWrapper packageManagerWrapper, SharedPreferences sharedPreferences) {
        super(ReportField.DEVICE_ID);
        this.context = context2;
        this.pm = packageManagerWrapper;
        this.prefs = sharedPreferences;
    }

    @SuppressLint({"HardwareIds"})
    private String getDeviceId() {
        try {
            return ((TelephonyManager) this.context.getSystemService("phone")).getDeviceId();
        } catch (RuntimeException e2) {
            ACRALog aCRALog = ACRA.log;
            String str = ACRA.LOG_TAG;
            aCRALog.w(str, "Couldn't retrieve DeviceId for : " + this.context.getPackageName(), e2);
            return null;
        }
    }

    /* access modifiers changed from: package-private */
    @Override // org.acra.collector.Collector
    public Element collect(ReportField reportField, ReportBuilder reportBuilder) {
        String deviceId = getDeviceId();
        return deviceId != null ? new StringElement(deviceId) : ACRAConstants.NOT_AVAILABLE;
    }

    /* access modifiers changed from: package-private */
    @Override // org.acra.collector.Collector
    public boolean shouldCollect(Set<ReportField> set, ReportField reportField, ReportBuilder reportBuilder) {
        if (!super.shouldCollect(set, reportField, reportBuilder) || !this.prefs.getBoolean(ACRA.PREF_ENABLE_DEVICE_ID, true) || !this.pm.hasPermission("android.permission.READ_PHONE_STATE")) {
            return false;
        }
        return true;
    }
}
