package org.acra.collector;

import android.content.Context;
import android.graphics.Point;
import android.graphics.Rect;
import android.os.Build;
import android.util.DisplayMetrics;
import android.util.SparseArray;
import android.view.Display;
import b.e.e.a.a;
import java.lang.reflect.Field;
import java.util.Arrays;
import java.util.Collection;
import org.acra.ACRA;
import org.acra.ReportField;
import org.acra.builder.ReportBuilder;
import org.acra.model.ComplexElement;
import org.acra.model.Element;
import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

/* access modifiers changed from: package-private */
public final class DisplayManagerCollector extends Collector {
    private final Context context;
    private final SparseArray<String> flagNames = new SparseArray<>();

    DisplayManagerCollector(Context context2) {
        super(ReportField.DISPLAY);
        this.context = context2;
    }

    private String activeFlags(int i) {
        StringBuilder sb = new StringBuilder();
        for (int i2 = 0; i2 < this.flagNames.size(); i2++) {
            int keyAt = this.flagNames.keyAt(i2) & i;
            if (keyAt > 0) {
                if (sb.length() > 0) {
                    sb.append('+');
                }
                sb.append(this.flagNames.get(keyAt));
            }
        }
        return sb.toString();
    }

    private static void collectCurrentSizeRange(Display display, JSONObject jSONObject) {
        if (Build.VERSION.SDK_INT >= 16) {
            Point point = new Point();
            Point point2 = new Point();
            display.getCurrentSizeRange(point, point2);
            JSONObject jSONObject2 = new JSONObject();
            jSONObject2.put("smallest", new JSONArray((Collection) Arrays.asList(Integer.valueOf(point.x), Integer.valueOf(point.y))));
            jSONObject2.put("largest", new JSONArray((Collection) Arrays.asList(Integer.valueOf(point2.x), Integer.valueOf(point2.y))));
            jSONObject.put("currentSizeRange", jSONObject2);
        }
    }

    private JSONObject collectDisplayData(Display display) {
        display.getMetrics(new DisplayMetrics());
        JSONObject jSONObject = new JSONObject();
        collectCurrentSizeRange(display, jSONObject);
        collectFlags(display, jSONObject);
        collectMetrics(display, jSONObject);
        collectRealMetrics(display, jSONObject);
        collectName(display, jSONObject);
        collectRealSize(display, jSONObject);
        collectRectSize(display, jSONObject);
        collectSize(display, jSONObject);
        collectRotation(display, jSONObject);
        collectIsValid(display, jSONObject);
        jSONObject.put("orientation", display.getRotation()).put("refreshRate", (double) display.getRefreshRate());
        jSONObject.put("height", display.getHeight()).put("width", display.getWidth()).put("pixelFormat", display.getPixelFormat());
        return jSONObject;
    }

    private void collectFlags(Display display, JSONObject jSONObject) {
        if (Build.VERSION.SDK_INT >= 17) {
            int flags = display.getFlags();
            Field[] fields = display.getClass().getFields();
            for (Field field : fields) {
                if (field.getName().startsWith("FLAG_")) {
                    try {
                        this.flagNames.put(field.getInt(null), field.getName());
                    } catch (IllegalAccessException unused) {
                    }
                }
            }
            jSONObject.put("flags", activeFlags(flags));
        }
    }

    private static void collectIsValid(Display display, JSONObject jSONObject) {
        if (Build.VERSION.SDK_INT >= 17) {
            jSONObject.put("isValid", display.isValid());
        }
    }

    private static void collectMetrics(Display display, JSONObject jSONObject) {
        DisplayMetrics displayMetrics = new DisplayMetrics();
        display.getMetrics(displayMetrics);
        JSONObject jSONObject2 = new JSONObject();
        collectMetrics(displayMetrics, jSONObject2);
        jSONObject.put("metrics", jSONObject2);
    }

    private static void collectName(Display display, JSONObject jSONObject) {
        if (Build.VERSION.SDK_INT >= 17) {
            jSONObject.put("name", display.getName());
        }
    }

    private static void collectRealMetrics(Display display, JSONObject jSONObject) {
        if (Build.VERSION.SDK_INT >= 17) {
            DisplayMetrics displayMetrics = new DisplayMetrics();
            display.getRealMetrics(displayMetrics);
            JSONObject jSONObject2 = new JSONObject();
            collectMetrics(displayMetrics, jSONObject2);
            jSONObject.put("realMetrics", jSONObject2);
        }
    }

    private static void collectRealSize(Display display, JSONObject jSONObject) {
        if (Build.VERSION.SDK_INT >= 17) {
            Point point = new Point();
            display.getRealSize(point);
            jSONObject.put("realSize", new JSONArray((Collection) Arrays.asList(Integer.valueOf(point.x), Integer.valueOf(point.y))));
        }
    }

    private static void collectRectSize(Display display, JSONObject jSONObject) {
        if (Build.VERSION.SDK_INT >= 13) {
            Rect rect = new Rect();
            display.getRectSize(rect);
            jSONObject.put("rectSize", new JSONArray((Collection) Arrays.asList(Integer.valueOf(rect.top), Integer.valueOf(rect.left), Integer.valueOf(rect.width()), Integer.valueOf(rect.height()))));
        }
    }

    private static void collectRotation(Display display, JSONObject jSONObject) {
        jSONObject.put("rotation", rotationToString(display.getRotation()));
    }

    private static void collectSize(Display display, JSONObject jSONObject) {
        if (Build.VERSION.SDK_INT >= 13) {
            Point point = new Point();
            display.getSize(point);
            jSONObject.put("size", new JSONArray((Collection) Arrays.asList(Integer.valueOf(point.x), Integer.valueOf(point.y))));
        }
    }

    private static String rotationToString(int i) {
        if (i == 0) {
            return "ROTATION_0";
        }
        if (i == 1) {
            return "ROTATION_90";
        }
        if (i != 2) {
            return i != 3 ? String.valueOf(i) : "ROTATION_270";
        }
        return "ROTATION_180";
    }

    /* access modifiers changed from: package-private */
    @Override // org.acra.collector.Collector
    public Element collect(ReportField reportField, ReportBuilder reportBuilder) {
        ComplexElement complexElement = new ComplexElement();
        Display[] a2 = a.b(this.context).a();
        for (Display display : a2) {
            try {
                complexElement.put(String.valueOf(display.getDisplayId()), collectDisplayData(display));
            } catch (JSONException e2) {
                ACRA.log.w(ACRA.LOG_TAG, "Failed to collect data for display " + display.getDisplayId(), e2);
            }
        }
        return complexElement;
    }

    private static void collectMetrics(DisplayMetrics displayMetrics, JSONObject jSONObject) {
        JSONObject put = jSONObject.put("density", (double) displayMetrics.density).put("densityDpi", displayMetrics.densityDpi);
        put.put("scaledDensity", "x" + displayMetrics.scaledDensity).put("widthPixels", displayMetrics.widthPixels).put("heightPixels", displayMetrics.heightPixels).put("xdpi", (double) displayMetrics.xdpi).put("ydpi", (double) displayMetrics.ydpi);
    }
}
