package org.acra.dialog;

import android.os.Bundle;
import b.h.a.d;
import java.io.File;
import java.io.IOException;
import java.io.Serializable;
import org.acra.ACRA;
import org.acra.ACRAConstants;
import org.acra.ReportField;
import org.acra.collector.CrashReportData;
import org.acra.config.ACRAConfiguration;
import org.acra.file.BulkReportDeleter;
import org.acra.file.CrashReportPersister;
import org.acra.log.ACRALog;
import org.acra.sender.SenderServiceStarter;
import org.acra.util.ToastSender;
import org.json.JSONException;

public abstract class BaseCrashReportDialog extends d {
    private ACRAConfiguration config;
    private Throwable exception;
    private File reportFile;

    /* access modifiers changed from: protected */
    public final void cancelReports() {
        new BulkReportDeleter(getApplicationContext()).deleteReports(false, 0);
    }

    /* access modifiers changed from: protected */
    public final ACRAConfiguration getConfig() {
        return this.config;
    }

    /* access modifiers changed from: protected */
    public final Throwable getException() {
        return this.exception;
    }

    /* access modifiers changed from: protected */
    public void init(Bundle bundle) {
    }

    /* access modifiers changed from: protected */
    @Override // androidx.core.app.d, b.h.a.d
    public final void onCreate(Bundle bundle) {
        preInit(bundle);
        super.onCreate(bundle);
        if (ACRA.DEV_LOGGING) {
            ACRALog aCRALog = ACRA.log;
            String str = ACRA.LOG_TAG;
            aCRALog.d(str, "CrashReportDialog extras=" + getIntent().getExtras());
        }
        Serializable serializableExtra = getIntent().getSerializableExtra(ACRAConstants.EXTRA_REPORT_CONFIG);
        Serializable serializableExtra2 = getIntent().getSerializableExtra(ACRAConstants.EXTRA_REPORT_FILE);
        Serializable serializableExtra3 = getIntent().getSerializableExtra(ACRAConstants.EXTRA_REPORT_EXCEPTION);
        if (getIntent().getBooleanExtra(ACRAConstants.EXTRA_FORCE_CANCEL, false)) {
            if (ACRA.DEV_LOGGING) {
                ACRA.log.d(ACRA.LOG_TAG, "Forced reports deletion.");
            }
            cancelReports();
            finish();
        } else if (!(serializableExtra instanceof ACRAConfiguration) || !(serializableExtra2 instanceof File) || (!(serializableExtra3 instanceof Throwable) && serializableExtra3 != null)) {
            ACRA.log.w(ACRA.LOG_TAG, "Illegal or incomplete call of BaseCrashReportDialog.");
            finish();
        } else {
            this.config = (ACRAConfiguration) serializableExtra;
            this.reportFile = (File) serializableExtra2;
            this.exception = (Throwable) serializableExtra3;
            init(bundle);
        }
    }

    /* access modifiers changed from: protected */
    public void preInit(Bundle bundle) {
    }

    /* access modifiers changed from: protected */
    public final void sendCrash(String str, String str2) {
        CrashReportPersister crashReportPersister = new CrashReportPersister();
        try {
            if (ACRA.DEV_LOGGING) {
                ACRALog aCRALog = ACRA.log;
                String str3 = ACRA.LOG_TAG;
                aCRALog.d(str3, "Add user comment to " + this.reportFile);
            }
            CrashReportData load = crashReportPersister.load(this.reportFile);
            ReportField reportField = ReportField.USER_COMMENT;
            if (str == null) {
                str = "";
            }
            load.putString(reportField, str);
            ReportField reportField2 = ReportField.USER_EMAIL;
            if (str2 == null) {
                str2 = "";
            }
            load.putString(reportField2, str2);
            crashReportPersister.store(load, this.reportFile);
        } catch (IOException e2) {
            ACRA.log.w(ACRA.LOG_TAG, "User comment not added: ", e2);
        } catch (JSONException e3) {
            ACRA.log.w(ACRA.LOG_TAG, "User comment not added: ", e3);
        }
        new SenderServiceStarter(getApplicationContext(), this.config).startService(false, true);
        int resDialogOkToast = this.config.resDialogOkToast();
        if (resDialogOkToast != 0) {
            ToastSender.sendToast(getApplicationContext(), resDialogOkToast, 1);
        }
    }
}
