package org.acra.file;

import java.io.BufferedInputStream;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.OutputStreamWriter;
import org.acra.ACRAConstants;
import org.acra.collector.CrashReportData;
import org.acra.util.IOUtils;
import org.acra.util.JsonUtils;
import org.json.JSONObject;

public final class CrashReportPersister {
    private static final String CHARSET = "UTF-8";

    public CrashReportData load(File file) {
        BufferedInputStream bufferedInputStream = new BufferedInputStream(new FileInputStream(file), ACRAConstants.DEFAULT_BUFFER_SIZE_IN_BYTES);
        try {
            return JsonUtils.toCrashReportData(new JSONObject(IOUtils.streamToString(bufferedInputStream)));
        } finally {
            IOUtils.safeClose(bufferedInputStream);
        }
    }

    public void store(CrashReportData crashReportData, File file) {
        OutputStreamWriter outputStreamWriter = new OutputStreamWriter(new FileOutputStream(file), CHARSET);
        try {
            outputStreamWriter.write(crashReportData.toJSON().toString());
            outputStreamWriter.flush();
        } finally {
            IOUtils.safeClose(outputStreamWriter);
        }
    }
}
