package org.acra.sender;

import android.app.IntentService;
import android.content.Intent;
import java.io.File;
import java.util.ArrayList;
import java.util.Collection;
import java.util.List;
import org.acra.ACRA;
import org.acra.collections.ImmutableSet;
import org.acra.config.ACRAConfiguration;
import org.acra.file.CrashReportFileNameParser;
import org.acra.file.ReportLocator;
import org.acra.log.ACRALog;

public class SenderService extends IntentService {
    public static final String EXTRA_ACRA_CONFIG = "acraConfig";
    public static final String EXTRA_APPROVE_REPORTS_FIRST = "approveReportsFirst";
    public static final String EXTRA_ONLY_SEND_SILENT_REPORTS = "onlySendSilentReports";
    private final ReportLocator locator = new ReportLocator(this);

    public SenderService() {
        super("ACRA SenderService");
        setIntentRedelivery(true);
    }

    private List<ReportSender> getSenderInstances(ACRAConfiguration aCRAConfiguration, Collection<Class<? extends ReportSenderFactory>> collection) {
        ArrayList arrayList = new ArrayList();
        for (Class<? extends ReportSenderFactory> cls : collection) {
            try {
                arrayList.add(((ReportSenderFactory) cls.newInstance()).create(getApplication(), aCRAConfiguration));
            } catch (InstantiationException e2) {
                ACRALog aCRALog = ACRA.log;
                String str = ACRA.LOG_TAG;
                aCRALog.w(str, "Could not construct ReportSender from " + cls, e2);
            } catch (IllegalAccessException e3) {
                ACRALog aCRALog2 = ACRA.log;
                String str2 = ACRA.LOG_TAG;
                aCRALog2.w(str2, "Could not construct ReportSender from " + cls, e3);
            }
        }
        return arrayList;
    }

    private void markReportsAsApproved() {
        if (ACRA.DEV_LOGGING) {
            ACRA.log.d(ACRA.LOG_TAG, "Mark all pending reports as approved.");
        }
        File[] unapprovedReports = this.locator.getUnapprovedReports();
        for (File file : unapprovedReports) {
            File file2 = new File(this.locator.getApprovedFolder(), file.getName());
            if (!file.renameTo(file2)) {
                ACRA.log.w(ACRA.LOG_TAG, "Could not rename approved report from " + file + " to " + file2);
            }
        }
    }

    /* access modifiers changed from: protected */
    public void onHandleIntent(Intent intent) {
        if (intent != null && intent.hasExtra(EXTRA_ACRA_CONFIG)) {
            int i = 0;
            boolean booleanExtra = intent.getBooleanExtra(EXTRA_ONLY_SEND_SILENT_REPORTS, false);
            boolean booleanExtra2 = intent.getBooleanExtra(EXTRA_APPROVE_REPORTS_FIRST, false);
            ACRAConfiguration aCRAConfiguration = (ACRAConfiguration) intent.getSerializableExtra(EXTRA_ACRA_CONFIG);
            ImmutableSet<Class<? extends ReportSenderFactory>> reportSenderFactoryClasses = aCRAConfiguration.reportSenderFactoryClasses();
            if (ACRA.DEV_LOGGING) {
                ACRA.log.d(ACRA.LOG_TAG, "About to start sending reports from SenderService");
            }
            try {
                List<ReportSender> senderInstances = getSenderInstances(aCRAConfiguration, reportSenderFactoryClasses);
                if (booleanExtra2) {
                    markReportsAsApproved();
                }
                File[] approvedReports = this.locator.getApprovedReports();
                ReportDistributor reportDistributor = new ReportDistributor(this, aCRAConfiguration, senderInstances);
                CrashReportFileNameParser crashReportFileNameParser = new CrashReportFileNameParser();
                int length = approvedReports.length;
                int i2 = 0;
                while (true) {
                    if (i >= length) {
                        break;
                    }
                    File file = approvedReports[i];
                    if (!booleanExtra || crashReportFileNameParser.isSilent(file.getName())) {
                        if (i2 >= 5) {
                            break;
                        }
                        reportDistributor.distribute(file);
                        i2++;
                    }
                    i++;
                }
            } catch (Exception e2) {
                ACRA.log.e(ACRA.LOG_TAG, "", e2);
            }
            if (ACRA.DEV_LOGGING) {
                ACRA.log.d(ACRA.LOG_TAG, "Finished sending reports from SenderService");
            }
        } else if (ACRA.DEV_LOGGING) {
            ACRA.log.d(ACRA.LOG_TAG, "SenderService was started but no valid intent was delivered, will now quit");
        }
    }
}
