package org.acra.util;

import android.content.Context;
import android.content.SharedPreferences;
import android.content.pm.PackageInfo;
import java.io.File;
import org.acra.ACRA;
import org.acra.ReportingInteractionMode;
import org.acra.config.ACRAConfiguration;
import org.acra.file.BulkReportDeleter;
import org.acra.file.CrashReportFileNameParser;
import org.acra.file.ReportLocator;
import org.acra.prefs.PrefUtils;
import org.acra.prefs.SharedPreferencesFactory;
import org.acra.sender.SenderServiceStarter;

public final class ApplicationStartupProcessor {
    private final ACRAConfiguration config;
    private final Context context;

    public ApplicationStartupProcessor(Context context2, ACRAConfiguration aCRAConfiguration) {
        this.context = context2;
        this.config = aCRAConfiguration;
    }

    private int getAppVersion() {
        PackageInfo packageInfo = new PackageManagerWrapper(this.context).getPackageInfo();
        if (packageInfo == null) {
            return 0;
        }
        return packageInfo.versionCode;
    }

    private boolean hasNonSilentApprovedReports(File[] fileArr) {
        CrashReportFileNameParser crashReportFileNameParser = new CrashReportFileNameParser();
        for (File file : fileArr) {
            if (!crashReportFileNameParser.isSilent(file.getName())) {
                return true;
            }
        }
        return false;
    }

    public void deleteAllUnapprovedReportsBarOne() {
        new BulkReportDeleter(this.context).deleteReports(false, 1);
    }

    public void deleteUnsentReportsFromOldAppVersion() {
        SharedPreferences create = new SharedPreferencesFactory(this.context, this.config).create();
        int appVersion = getAppVersion();
        if (((long) appVersion) > ((long) create.getInt(ACRA.PREF_LAST_VERSION_NR, 0))) {
            BulkReportDeleter bulkReportDeleter = new BulkReportDeleter(this.context);
            bulkReportDeleter.deleteReports(true, 0);
            bulkReportDeleter.deleteReports(false, 0);
            SharedPreferences.Editor edit = create.edit();
            edit.putInt(ACRA.PREF_LAST_VERSION_NR, appVersion);
            PrefUtils.save(edit);
        }
    }

    public void sendApprovedReports() {
        File[] approvedReports = new ReportLocator(this.context).getApprovedReports();
        if (approvedReports.length != 0) {
            if (this.config.mode() == ReportingInteractionMode.TOAST && hasNonSilentApprovedReports(approvedReports)) {
                ToastSender.sendToast(this.context, this.config.resToastText(), 1);
            }
            new SenderServiceStarter(this.context, this.config).startService(false, false);
        }
    }
}
