package org.acra.util;

import android.text.TextUtils;
import com.android.internal.util.Predicate;
import java.io.BufferedReader;
import java.io.Closeable;
import java.io.File;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.util.LinkedList;
import java.util.List;
import org.acra.ACRA;
import org.acra.ACRAConstants;
import org.acra.collections.BoundedLinkedList;
import org.acra.log.ACRALog;

public final class IOUtils {
    private static final Predicate<String> DEFAULT_FILTER = new Predicate<String>() {
        /* class org.acra.util.IOUtils.AnonymousClass1 */

        public boolean apply(String str) {
            return true;
        }
    };
    private static final int NO_LIMIT = -1;
    private static final int READ_TIMEOUT = 3000;

    private IOUtils() {
    }

    public static void deleteReport(File file) {
        if (!file.delete()) {
            ACRALog aCRALog = ACRA.log;
            String str = ACRA.LOG_TAG;
            aCRALog.w(str, "Could not delete error report : " + file);
        }
    }

    public static void safeClose(Closeable closeable) {
        if (closeable != null) {
            try {
                closeable.close();
            } catch (IOException unused) {
            }
        }
    }

    public static String streamToString(InputStream inputStream) {
        return streamToString(inputStream, DEFAULT_FILTER, NO_LIMIT);
    }

    public static String streamToStringNonBlockingRead(InputStream inputStream, Predicate<String> predicate, int i) {
        LinkedList linkedList;
        NonBlockingBufferedReader nonBlockingBufferedReader = new NonBlockingBufferedReader(new BufferedReader(new InputStreamReader(inputStream), ACRAConstants.DEFAULT_BUFFER_SIZE_IN_BYTES));
        if (i == NO_LIMIT) {
            try {
                linkedList = new LinkedList();
            } catch (Throwable th) {
                nonBlockingBufferedReader.close();
                throw th;
            }
        } else {
            linkedList = new BoundedLinkedList(i);
        }
        long currentTimeMillis = System.currentTimeMillis() + 3000;
        while (true) {
            try {
                if (System.currentTimeMillis() >= currentTimeMillis) {
                    break;
                }
                String readLine = nonBlockingBufferedReader.readLine();
                if (readLine == null) {
                    break;
                } else if (predicate.apply(readLine)) {
                    linkedList.add(readLine);
                }
            } catch (InterruptedException e2) {
                if (ACRA.DEV_LOGGING) {
                    ACRA.log.d(ACRA.LOG_TAG, "Interrupted while reading stream", e2);
                }
            }
        }
        String join = TextUtils.join("\n", linkedList);
        nonBlockingBufferedReader.close();
        return join;
    }

    public static String streamToString(InputStream inputStream, Predicate<String> predicate) {
        return streamToString(inputStream, predicate, NO_LIMIT);
    }

    public static String streamToString(InputStream inputStream, int i) {
        return streamToString(inputStream, DEFAULT_FILTER, i);
    }

    public static String streamToString(InputStream inputStream, Predicate<String> predicate, int i) {
        List list;
        BufferedReader bufferedReader = new BufferedReader(new InputStreamReader(inputStream), ACRAConstants.DEFAULT_BUFFER_SIZE_IN_BYTES);
        if (i == NO_LIMIT) {
            try {
                list = new LinkedList();
            } catch (Throwable th) {
                safeClose(bufferedReader);
                throw th;
            }
        } else {
            list = new BoundedLinkedList(i);
        }
        while (true) {
            String readLine = bufferedReader.readLine();
            if (readLine == null) {
                String join = TextUtils.join("\n", list);
                safeClose(bufferedReader);
                return join;
            } else if (predicate.apply(readLine)) {
                list.add(readLine);
            }
        }
    }
}
