package org.acra.util;

import java.io.BufferedReader;
import java.io.IOException;
import java.util.concurrent.BlockingQueue;
import java.util.concurrent.LinkedBlockingQueue;
import java.util.concurrent.TimeUnit;

/* access modifiers changed from: package-private */
public final class NonBlockingBufferedReader {
    private Thread backgroundReaderThread = null;
    private volatile IOException exception = null;
    private final BlockingQueue<String> lines = new LinkedBlockingQueue();

    NonBlockingBufferedReader(final BufferedReader bufferedReader) {
        Thread thread = new Thread(new Runnable() {
            /* class org.acra.util.NonBlockingBufferedReader.AnonymousClass1 */

            public void run() {
                while (true) {
                    try {
                        if (Thread.interrupted()) {
                            break;
                        }
                        String readLine = bufferedReader.readLine();
                        if (readLine == null) {
                            break;
                        }
                        NonBlockingBufferedReader.this.lines.add(readLine);
                    } catch (IOException e2) {
                        NonBlockingBufferedReader.this.exception = e2;
                    } catch (Throwable th) {
                        IOUtils.safeClose(bufferedReader);
                        throw th;
                    }
                }
                IOUtils.safeClose(bufferedReader);
            }
        });
        this.backgroundReaderThread = thread;
        thread.setDaemon(true);
        this.backgroundReaderThread.start();
    }

    /* access modifiers changed from: package-private */
    public void close() {
        Thread thread = this.backgroundReaderThread;
        if (thread != null) {
            thread.interrupt();
            this.backgroundReaderThread = null;
        }
    }

    /* access modifiers changed from: package-private */
    public String readLine() {
        if (this.exception != null) {
            throw this.exception;
        } else if (this.lines.isEmpty()) {
            return null;
        } else {
            return this.lines.poll(500, TimeUnit.MILLISECONDS);
        }
    }
}
