package org.acra.util;

import android.app.Activity;
import android.app.ActivityManager;
import android.content.Context;
import android.content.Intent;
import android.os.Process;
import java.util.List;
import org.acra.ACRA;
import org.acra.builder.LastActivityManager;
import org.acra.config.ACRAConfiguration;
import org.acra.log.ACRALog;
import org.acra.sender.SenderService;

public final class ProcessFinisher {
    private final ACRAConfiguration config;
    private final Context context;
    private final LastActivityManager lastActivityManager;

    public ProcessFinisher(Context context2, ACRAConfiguration aCRAConfiguration, LastActivityManager lastActivityManager2) {
        this.context = context2;
        this.config = aCRAConfiguration;
        this.lastActivityManager = lastActivityManager2;
    }

    private void killProcessAndExit() {
        Process.killProcess(Process.myPid());
        System.exit(10);
    }

    private void stopServices() {
        if (this.config.stopServicesOnCrash()) {
            List<ActivityManager.RunningServiceInfo> runningServices = ((ActivityManager) this.context.getSystemService("activity")).getRunningServices(Integer.MAX_VALUE);
            int myPid = Process.myPid();
            for (ActivityManager.RunningServiceInfo runningServiceInfo : runningServices) {
                if (runningServiceInfo.pid == myPid && !SenderService.class.getName().equals(runningServiceInfo.service.getClassName())) {
                    try {
                        Intent intent = new Intent();
                        intent.setComponent(runningServiceInfo.service);
                        this.context.stopService(intent);
                    } catch (SecurityException unused) {
                        if (ACRA.DEV_LOGGING) {
                            ACRALog aCRALog = ACRA.log;
                            String str = ACRA.LOG_TAG;
                            aCRALog.d(str, "Unable to stop Service " + runningServiceInfo.service.getClassName() + ". Permission denied");
                        }
                    }
                }
            }
        }
    }

    public void endApplication(Thread thread) {
        finishLastActivity(thread);
        stopServices();
        killProcessAndExit();
    }

    public void finishLastActivity(Thread thread) {
        final Activity lastActivity = this.lastActivityManager.getLastActivity();
        if (lastActivity != null) {
            if (ACRA.DEV_LOGGING) {
                ACRA.log.d(ACRA.LOG_TAG, "Finishing the last Activity prior to killing the Process");
            }
            lastActivity.runOnUiThread(new Runnable() {
                /* class org.acra.util.ProcessFinisher.AnonymousClass1 */

                public void run() {
                    lastActivity.finish();
                    if (ACRA.DEV_LOGGING) {
                        ACRALog aCRALog = ACRA.log;
                        String str = ACRA.LOG_TAG;
                        aCRALog.d(str, "Finished " + lastActivity.getClass());
                    }
                }
            });
            if (thread != lastActivity.getMainLooper().getThread()) {
                this.lastActivityManager.waitForActivityStop(100);
            }
            this.lastActivityManager.clearLastActivity();
        }
    }
}
