package androidx.core.graphics.drawable;

import android.content.res.ColorStateList;
import android.graphics.Bitmap;
import android.graphics.PorterDuff;
import android.graphics.drawable.Icon;
import android.os.Build;
import android.os.Parcelable;
import android.util.Log;
import androidx.versionedparcelable.CustomVersionedParcelable;
import java.io.ByteArrayOutputStream;
import java.lang.reflect.InvocationTargetException;
import java.nio.charset.Charset;

public class IconCompat extends CustomVersionedParcelable {
    static final PorterDuff.Mode j = PorterDuff.Mode.SRC_IN;

    /* renamed from: a  reason: collision with root package name */
    public int f636a;

    /* renamed from: b  reason: collision with root package name */
    Object f637b;

    /* renamed from: c  reason: collision with root package name */
    public byte[] f638c;

    /* renamed from: d  reason: collision with root package name */
    public Parcelable f639d;

    /* renamed from: e  reason: collision with root package name */
    public int f640e;

    /* renamed from: f  reason: collision with root package name */
    public int f641f;
    public ColorStateList g = null;
    PorterDuff.Mode h = j;
    public String i;

    private static int b(Icon icon) {
        if (Build.VERSION.SDK_INT >= 28) {
            return icon.getResId();
        }
        try {
            return ((Integer) icon.getClass().getMethod("getResId", new Class[0]).invoke(icon, new Object[0])).intValue();
        } catch (IllegalAccessException e2) {
            Log.e("IconCompat", "Unable to get icon resource", e2);
            return 0;
        } catch (InvocationTargetException e3) {
            Log.e("IconCompat", "Unable to get icon resource", e3);
            return 0;
        } catch (NoSuchMethodException e4) {
            Log.e("IconCompat", "Unable to get icon resource", e4);
            return 0;
        }
    }

    private static String d(Icon icon) {
        if (Build.VERSION.SDK_INT >= 28) {
            return icon.getResPackage();
        }
        try {
            return (String) icon.getClass().getMethod("getResPackage", new Class[0]).invoke(icon, new Object[0]);
        } catch (IllegalAccessException e2) {
            Log.e("IconCompat", "Unable to get icon package", e2);
            return null;
        } catch (InvocationTargetException e3) {
            Log.e("IconCompat", "Unable to get icon package", e3);
            return null;
        } catch (NoSuchMethodException e4) {
            Log.e("IconCompat", "Unable to get icon package", e4);
            return null;
        }
    }

    private static String g(int i2) {
        return i2 != 1 ? i2 != 2 ? i2 != 3 ? i2 != 4 ? i2 != 5 ? "UNKNOWN" : "BITMAP_MASKABLE" : "URI" : "DATA" : "RESOURCE" : "BITMAP";
    }

    public int a() {
        int i2 = this.f636a;
        if (i2 == -1 && Build.VERSION.SDK_INT >= 23) {
            return b((Icon) this.f637b);
        }
        if (i2 == 2) {
            return this.f640e;
        }
        throw new IllegalStateException("called getResId() on " + this);
    }

    public String c() {
        int i2 = this.f636a;
        if (i2 == -1 && Build.VERSION.SDK_INT >= 23) {
            return d((Icon) this.f637b);
        }
        if (i2 == 2) {
            return ((String) this.f637b).split(":", -1)[0];
        }
        throw new IllegalStateException("called getResPackage() on " + this);
    }

    public void e() {
        this.h = PorterDuff.Mode.valueOf(this.i);
        int i2 = this.f636a;
        if (i2 != -1) {
            if (i2 != 1) {
                if (i2 != 2) {
                    if (i2 == 3) {
                        this.f637b = this.f638c;
                        return;
                    } else if (i2 != 4) {
                        if (i2 != 5) {
                            return;
                        }
                    }
                }
                this.f637b = new String(this.f638c, Charset.forName("UTF-16"));
                return;
            }
            Parcelable parcelable = this.f639d;
            if (parcelable != null) {
                this.f637b = parcelable;
                return;
            }
            byte[] bArr = this.f638c;
            this.f637b = bArr;
            this.f636a = 3;
            this.f640e = 0;
            this.f641f = bArr.length;
            return;
        }
        Parcelable parcelable2 = this.f639d;
        if (parcelable2 != null) {
            this.f637b = parcelable2;
            return;
        }
        throw new IllegalArgumentException("Invalid icon");
    }

    public void f(boolean z) {
        this.i = this.h.name();
        int i2 = this.f636a;
        if (i2 != -1) {
            if (i2 != 1) {
                if (i2 == 2) {
                    this.f638c = ((String) this.f637b).getBytes(Charset.forName("UTF-16"));
                    return;
                } else if (i2 == 3) {
                    this.f638c = (byte[]) this.f637b;
                    return;
                } else if (i2 == 4) {
                    this.f638c = this.f637b.toString().getBytes(Charset.forName("UTF-16"));
                    return;
                } else if (i2 != 5) {
                    return;
                }
            }
            if (z) {
                ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
                ((Bitmap) this.f637b).compress(Bitmap.CompressFormat.PNG, 90, byteArrayOutputStream);
                this.f638c = byteArrayOutputStream.toByteArray();
                return;
            }
            this.f639d = (Parcelable) this.f637b;
        } else if (!z) {
            this.f639d = (Parcelable) this.f637b;
        } else {
            throw new IllegalArgumentException("Can't serialize Icon created with IconCompat#createFromIcon");
        }
    }

    /* JADX WARNING: Code restructure failed: missing block: B:13:0x002b, code lost:
        if (r1 != 5) goto L_0x009a;
     */
    /* JADX WARNING: Removed duplicated region for block: B:22:0x009e  */
    /* JADX WARNING: Removed duplicated region for block: B:25:0x00ae  */
    public String toString() {
        if (this.f636a == -1) {
            return String.valueOf(this.f637b);
        }
        StringBuilder sb = new StringBuilder("Icon(typ=");
        sb.append(g(this.f636a));
        int i2 = this.f636a;
        if (i2 != 1) {
            if (i2 == 2) {
                sb.append(" pkg=");
                sb.append(c());
                sb.append(" id=");
                sb.append(String.format("0x%08x", Integer.valueOf(a())));
            } else if (i2 == 3) {
                sb.append(" len=");
                sb.append(this.f640e);
                if (this.f641f != 0) {
                    sb.append(" off=");
                    sb.append(this.f641f);
                }
            } else if (i2 == 4) {
                sb.append(" uri=");
                sb.append(this.f637b);
            }
            if (this.g != null) {
                sb.append(" tint=");
                sb.append(this.g);
            }
            if (this.h != j) {
                sb.append(" mode=");
                sb.append(this.h);
            }
            sb.append(")");
            return sb.toString();
        }
        sb.append(" size=");
        sb.append(((Bitmap) this.f637b).getWidth());
        sb.append("x");
        sb.append(((Bitmap) this.f637b).getHeight());
        if (this.g != null) {
        }
        if (this.h != j) {
        }
        sb.append(")");
        return sb.toString();
    }
}
