package org.acra.builder;

import android.app.Activity;
import android.app.Application;
import android.os.Build;
import android.os.Bundle;
import java.lang.ref.WeakReference;
import org.acra.ACRA;
import org.acra.dialog.BaseCrashReportDialog;
import org.acra.log.ACRALog;

public final class LastActivityManager {
    private WeakReference<Activity> lastActivityCreated = new WeakReference<>(null);

    public LastActivityManager(Application application) {
        if (Build.VERSION.SDK_INT >= 14) {
            application.registerActivityLifecycleCallbacks(new Application.ActivityLifecycleCallbacks() {
                /* class org.acra.builder.LastActivityManager.AnonymousClass1 */

                public void onActivityCreated(Activity activity, Bundle bundle) {
                    if (ACRA.DEV_LOGGING) {
                        ACRALog aCRALog = ACRA.log;
                        String str = ACRA.LOG_TAG;
                        aCRALog.d(str, "onActivityCreated " + activity.getClass());
                    }
                    if (!(activity instanceof BaseCrashReportDialog)) {
                        LastActivityManager.this.lastActivityCreated = new WeakReference(activity);
                    }
                }

                public void onActivityDestroyed(Activity activity) {
                    if (ACRA.DEV_LOGGING) {
                        ACRALog aCRALog = ACRA.log;
                        String str = ACRA.LOG_TAG;
                        aCRALog.d(str, "onActivityDestroyed " + activity.getClass());
                    }
                }

                public void onActivityPaused(Activity activity) {
                    if (ACRA.DEV_LOGGING) {
                        ACRALog aCRALog = ACRA.log;
                        String str = ACRA.LOG_TAG;
                        aCRALog.d(str, "onActivityPaused " + activity.getClass());
                    }
                }

                public void onActivityResumed(Activity activity) {
                    if (ACRA.DEV_LOGGING) {
                        ACRALog aCRALog = ACRA.log;
                        String str = ACRA.LOG_TAG;
                        aCRALog.d(str, "onActivityResumed " + activity.getClass());
                    }
                }

                public void onActivitySaveInstanceState(Activity activity, Bundle bundle) {
                    if (ACRA.DEV_LOGGING) {
                        ACRALog aCRALog = ACRA.log;
                        String str = ACRA.LOG_TAG;
                        aCRALog.d(str, "onActivitySaveInstanceState " + activity.getClass());
                    }
                }

                public void onActivityStarted(Activity activity) {
                    if (ACRA.DEV_LOGGING) {
                        ACRALog aCRALog = ACRA.log;
                        String str = ACRA.LOG_TAG;
                        aCRALog.d(str, "onActivityStarted " + activity.getClass());
                    }
                }

                public void onActivityStopped(Activity activity) {
                    if (ACRA.DEV_LOGGING) {
                        ACRALog aCRALog = ACRA.log;
                        String str = ACRA.LOG_TAG;
                        aCRALog.d(str, "onActivityStopped " + activity.getClass());
                    }
                    synchronized (this) {
                        notify();
                    }
                }
            });
        }
    }

    public void clearLastActivity() {
        this.lastActivityCreated.clear();
    }

    public Activity getLastActivity() {
        return this.lastActivityCreated.get();
    }

    /* JADX WARNING: Exception block dominator not found, dom blocks: [] */
    /* JADX WARNING: Missing exception handler attribute for start block: B:5:0x0008 */
    public void waitForActivityStop(int i) {
        synchronized (this) {
            wait((long) i);
        }
    }
}
