package org.acra.collector;

import android.content.Context;
import android.content.res.Configuration;
import android.util.SparseArray;
import java.lang.reflect.Field;
import java.lang.reflect.Modifier;
import java.util.HashMap;
import java.util.Map;
import org.acra.ACRA;
import org.acra.ACRAConstants;
import org.acra.ReportField;
import org.acra.builder.ReportBuilder;
import org.acra.log.ACRALog;
import org.acra.model.ComplexElement;
import org.acra.model.Element;
import org.json.JSONException;

public final class ConfigurationCollector extends Collector {
    private static final String FIELD_MCC = "mcc";
    private static final String FIELD_MNC = "mnc";
    private static final String FIELD_SCREENLAYOUT = "screenLayout";
    private static final String FIELD_UIMODE = "uiMode";
    private static final String PREFIX_HARDKEYBOARDHIDDEN = "HARDKEYBOARDHIDDEN_";
    private static final String PREFIX_KEYBOARD = "KEYBOARD_";
    private static final String PREFIX_KEYBOARDHIDDEN = "KEYBOARDHIDDEN_";
    private static final String PREFIX_NAVIGATION = "NAVIGATION_";
    private static final String PREFIX_NAVIGATIONHIDDEN = "NAVIGATIONHIDDEN_";
    private static final String PREFIX_ORIENTATION = "ORIENTATION_";
    private static final String PREFIX_SCREENLAYOUT = "SCREENLAYOUT_";
    private static final String PREFIX_TOUCHSCREEN = "TOUCHSCREEN_";
    private static final String PREFIX_UI_MODE = "UI_MODE_";
    private static final String SUFFIX_MASK = "_MASK";
    private final Context context;
    private final Element initialConfiguration;

    /* renamed from: org.acra.collector.ConfigurationCollector$1  reason: invalid class name */
    static /* synthetic */ class AnonymousClass1 {
        static final /* synthetic */ int[] $SwitchMap$org$acra$ReportField;

        /* JADX WARNING: Can't wrap try/catch for region: R(6:0|1|2|3|4|6) */
        /* JADX WARNING: Code restructure failed: missing block: B:7:?, code lost:
            return;
         */
        /* JADX WARNING: Failed to process nested try/catch */
        /* JADX WARNING: Missing exception handler attribute for start block: B:3:0x0012 */
        static {
            int[] iArr = new int[ReportField.values().length];
            $SwitchMap$org$acra$ReportField = iArr;
            iArr[ReportField.INITIAL_CONFIGURATION.ordinal()] = 1;
            $SwitchMap$org$acra$ReportField[ReportField.CRASH_CONFIGURATION.ordinal()] = 2;
        }
    }

    public ConfigurationCollector(Context context2, Element element) {
        super(ReportField.INITIAL_CONFIGURATION, ReportField.CRASH_CONFIGURATION);
        this.context = context2;
        this.initialConfiguration = element;
    }

    private static String activeFlags(SparseArray<String> sparseArray, int i) {
        int i2;
        StringBuilder sb = new StringBuilder();
        for (int i3 = 0; i3 < sparseArray.size(); i3++) {
            int keyAt = sparseArray.keyAt(i3);
            if (sparseArray.get(keyAt).endsWith(SUFFIX_MASK) && (i2 = keyAt & i) > 0) {
                if (sb.length() > 0) {
                    sb.append('+');
                }
                sb.append(sparseArray.get(i2));
            }
        }
        return sb.toString();
    }

    public static Element collectConfiguration(Context context2) {
        try {
            return configToElement(context2.getResources().getConfiguration());
        } catch (RuntimeException e2) {
            ACRALog aCRALog = ACRA.log;
            String str = ACRA.LOG_TAG;
            aCRALog.w(str, "Couldn't retrieve CrashConfiguration for : " + context2.getPackageName(), e2);
            return ACRAConstants.NOT_AVAILABLE;
        }
    }

    private static Element configToElement(Configuration configuration) {
        ComplexElement complexElement = new ComplexElement();
        Map<String, SparseArray<String>> valueArrays = getValueArrays();
        Field[] fields = configuration.getClass().getFields();
        for (Field field : fields) {
            try {
                if (!Modifier.isStatic(field.getModifiers())) {
                    String name = field.getName();
                    try {
                        if (field.getType().equals(Integer.TYPE)) {
                            complexElement.put(name, getFieldValueName(valueArrays, configuration, field));
                        } else if (field.get(configuration) != null) {
                            complexElement.put(name, field.get(configuration));
                        }
                    } catch (JSONException e2) {
                        ACRA.log.w(ACRA.LOG_TAG, "Could not collect configuration field " + name, e2);
                    }
                }
            } catch (IllegalArgumentException e3) {
                ACRA.log.e(ACRA.LOG_TAG, "Error while inspecting device configuration: ", e3);
            } catch (IllegalAccessException e4) {
                ACRA.log.e(ACRA.LOG_TAG, "Error while inspecting device configuration: ", e4);
            }
        }
        return complexElement;
    }

    private static Object getFieldValueName(Map<String, SparseArray<String>> map, Configuration configuration, Field field) {
        String name = field.getName();
        if (name.equals(FIELD_MCC) || name.equals(FIELD_MNC)) {
            return Integer.valueOf(field.getInt(configuration));
        }
        if (name.equals(FIELD_UIMODE)) {
            return activeFlags(map.get(PREFIX_UI_MODE), field.getInt(configuration));
        }
        if (name.equals(FIELD_SCREENLAYOUT)) {
            return activeFlags(map.get(PREFIX_SCREENLAYOUT), field.getInt(configuration));
        }
        SparseArray<String> sparseArray = map.get(name.toUpperCase() + '_');
        if (sparseArray == null) {
            return Integer.valueOf(field.getInt(configuration));
        }
        String str = sparseArray.get(field.getInt(configuration));
        return str == null ? Integer.valueOf(field.getInt(configuration)) : str;
    }

    /* JADX WARNING: Code restructure failed: missing block: B:15:0x0095, code lost:
        r0 = e;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:41:0x00f5, code lost:
        r0 = e;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:57:0x011f, code lost:
        r0 = e;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:76:0x014d, code lost:
        r0 = e;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:79:0x0153, code lost:
        r0 = e;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:82:0x015b, code lost:
        r0 = e;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:83:0x015c, code lost:
        r13 = r11;
        r2 = r10;
        r1 = r9;
     */
    /* JADX WARNING: Failed to process nested try/catch */
    /* JADX WARNING: Removed duplicated region for block: B:15:0x0095 A[ExcHandler: IllegalAccessException (e java.lang.IllegalAccessException), Splitter:B:12:0x0086] */
    /* JADX WARNING: Removed duplicated region for block: B:76:0x014d A[ExcHandler: IllegalAccessException (e java.lang.IllegalAccessException), PHI: r2 
      PHI: (r2v14 android.util.SparseArray) = (r2v16 android.util.SparseArray), (r2v21 android.util.SparseArray), (r2v21 android.util.SparseArray) binds: [B:65:0x0134, B:55:0x011b, B:56:?] A[DONT_GENERATE, DONT_INLINE], Splitter:B:55:0x011b] */
    /* JADX WARNING: Removed duplicated region for block: B:79:0x0153 A[ExcHandler: IllegalAccessException (e java.lang.IllegalAccessException), PHI: r1 
      PHI: (r1v15 android.util.SparseArray) = (r1v16 android.util.SparseArray), (r1v16 android.util.SparseArray), (r1v21 android.util.SparseArray), (r1v21 android.util.SparseArray) binds: [B:49:0x010f, B:50:?, B:38:0x00ed, B:39:?] A[DONT_GENERATE, DONT_INLINE], Splitter:B:38:0x00ed] */
    private static Map<String, SparseArray<String>> getValueArrays() {
        int i;
        Field[] fieldArr;
        SparseArray sparseArray;
        String str;
        SparseArray sparseArray2;
        SparseArray sparseArray3;
        IllegalArgumentException e2;
        IllegalAccessException e3;
        String str2 = "Error while inspecting device configuration: ";
        HashMap hashMap = new HashMap();
        SparseArray sparseArray4 = new SparseArray();
        SparseArray sparseArray5 = new SparseArray();
        SparseArray sparseArray6 = new SparseArray();
        SparseArray sparseArray7 = new SparseArray();
        SparseArray sparseArray8 = new SparseArray();
        SparseArray sparseArray9 = new SparseArray();
        SparseArray sparseArray10 = new SparseArray();
        SparseArray sparseArray11 = new SparseArray();
        SparseArray sparseArray12 = new SparseArray();
        Field[] fields = Configuration.class.getFields();
        int length = fields.length;
        int i2 = 0;
        while (i2 < length) {
            Field field = fields[i2];
            if (!Modifier.isStatic(field.getModifiers()) || !Modifier.isFinal(field.getModifiers())) {
                fieldArr = fields;
                i = i2;
                str = str2;
                sparseArray = sparseArray12;
                sparseArray2 = sparseArray11;
                sparseArray3 = sparseArray10;
            } else {
                fieldArr = fields;
                String name = field.getName();
                try {
                    i = i2;
                    if (name.startsWith(PREFIX_HARDKEYBOARDHIDDEN)) {
                        try {
                            sparseArray4.put(field.getInt(null), name);
                        } catch (IllegalArgumentException e4) {
                            e2 = e4;
                            str = str2;
                            sparseArray = sparseArray12;
                            sparseArray2 = sparseArray11;
                            sparseArray3 = sparseArray10;
                            ACRA.log.w(ACRA.LOG_TAG, str, e2);
                            i2 = i + 1;
                            sparseArray10 = sparseArray3;
                            sparseArray11 = sparseArray2;
                            str2 = str;
                            sparseArray12 = sparseArray;
                            hashMap = hashMap;
                            length = length;
                            fields = fieldArr;
                        } catch (IllegalAccessException e5) {
                        }
                    } else if (name.startsWith(PREFIX_KEYBOARD)) {
                        sparseArray5.put(field.getInt(null), name);
                    } else if (name.startsWith(PREFIX_KEYBOARDHIDDEN)) {
                        sparseArray6.put(field.getInt(null), name);
                    } else if (name.startsWith(PREFIX_NAVIGATION)) {
                        sparseArray7.put(field.getInt(null), name);
                    } else if (name.startsWith(PREFIX_NAVIGATIONHIDDEN)) {
                        sparseArray8.put(field.getInt(null), name);
                    } else if (name.startsWith(PREFIX_ORIENTATION)) {
                        sparseArray9.put(field.getInt(null), name);
                    } else if (name.startsWith(PREFIX_SCREENLAYOUT)) {
                        try {
                            sparseArray3 = sparseArray10;
                            try {
                                sparseArray3.put(field.getInt(null), name);
                                sparseArray = sparseArray12;
                                sparseArray2 = sparseArray11;
                                str = str2;
                            } catch (IllegalArgumentException e6) {
                                e2 = e6;
                                sparseArray = sparseArray12;
                                sparseArray2 = sparseArray11;
                                str = str2;
                                ACRA.log.w(ACRA.LOG_TAG, str, e2);
                                i2 = i + 1;
                                sparseArray10 = sparseArray3;
                                sparseArray11 = sparseArray2;
                                str2 = str;
                                sparseArray12 = sparseArray;
                                hashMap = hashMap;
                                length = length;
                                fields = fieldArr;
                            } catch (IllegalAccessException e7) {
                            }
                        } catch (IllegalArgumentException e8) {
                            e2 = e8;
                            sparseArray3 = sparseArray10;
                            str = str2;
                            sparseArray = sparseArray12;
                            sparseArray2 = sparseArray11;
                            ACRA.log.w(ACRA.LOG_TAG, str, e2);
                            i2 = i + 1;
                            sparseArray10 = sparseArray3;
                            sparseArray11 = sparseArray2;
                            str2 = str;
                            sparseArray12 = sparseArray;
                            hashMap = hashMap;
                            length = length;
                            fields = fieldArr;
                        } catch (IllegalAccessException e9) {
                            e3 = e9;
                            sparseArray3 = sparseArray10;
                            sparseArray = sparseArray12;
                            sparseArray2 = sparseArray11;
                            str = str2;
                            ACRA.log.w(ACRA.LOG_TAG, str, e3);
                            i2 = i + 1;
                            sparseArray10 = sparseArray3;
                            sparseArray11 = sparseArray2;
                            str2 = str;
                            sparseArray12 = sparseArray;
                            hashMap = hashMap;
                            length = length;
                            fields = fieldArr;
                        }
                    } else {
                        sparseArray3 = sparseArray10;
                        if (name.startsWith(PREFIX_TOUCHSCREEN)) {
                            try {
                                sparseArray2 = sparseArray11;
                                try {
                                    sparseArray2.put(field.getInt(null), name);
                                } catch (IllegalArgumentException e10) {
                                    e2 = e10;
                                    sparseArray = sparseArray12;
                                    str = str2;
                                    ACRA.log.w(ACRA.LOG_TAG, str, e2);
                                    i2 = i + 1;
                                    sparseArray10 = sparseArray3;
                                    sparseArray11 = sparseArray2;
                                    str2 = str;
                                    sparseArray12 = sparseArray;
                                    hashMap = hashMap;
                                    length = length;
                                    fields = fieldArr;
                                } catch (IllegalAccessException e11) {
                                }
                            } catch (IllegalArgumentException e12) {
                                e2 = e12;
                                sparseArray2 = sparseArray11;
                                str = str2;
                                sparseArray = sparseArray12;
                                ACRA.log.w(ACRA.LOG_TAG, str, e2);
                                i2 = i + 1;
                                sparseArray10 = sparseArray3;
                                sparseArray11 = sparseArray2;
                                str2 = str;
                                sparseArray12 = sparseArray;
                                hashMap = hashMap;
                                length = length;
                                fields = fieldArr;
                            } catch (IllegalAccessException e13) {
                                e3 = e13;
                                sparseArray2 = sparseArray11;
                                sparseArray = sparseArray12;
                                str = str2;
                                ACRA.log.w(ACRA.LOG_TAG, str, e3);
                                i2 = i + 1;
                                sparseArray10 = sparseArray3;
                                sparseArray11 = sparseArray2;
                                str2 = str;
                                sparseArray12 = sparseArray;
                                hashMap = hashMap;
                                length = length;
                                fields = fieldArr;
                            }
                        } else {
                            sparseArray2 = sparseArray11;
                            if (name.startsWith(PREFIX_UI_MODE)) {
                                int i3 = field.getInt(null);
                                sparseArray = sparseArray12;
                                try {
                                    sparseArray.put(i3, name);
                                    str = str2;
                                } catch (IllegalArgumentException e14) {
                                    e2 = e14;
                                } catch (IllegalAccessException e15) {
                                    e3 = e15;
                                    str = str2;
                                    ACRA.log.w(ACRA.LOG_TAG, str, e3);
                                    i2 = i + 1;
                                    sparseArray10 = sparseArray3;
                                    sparseArray11 = sparseArray2;
                                    str2 = str;
                                    sparseArray12 = sparseArray;
                                    hashMap = hashMap;
                                    length = length;
                                    fields = fieldArr;
                                }
                            }
                        }
                        sparseArray = sparseArray12;
                        str = str2;
                    }
                    sparseArray = sparseArray12;
                    sparseArray2 = sparseArray11;
                    sparseArray3 = sparseArray10;
                    str = str2;
                } catch (IllegalArgumentException e16) {
                    e2 = e16;
                    i = i2;
                    str = str2;
                    sparseArray = sparseArray12;
                    sparseArray2 = sparseArray11;
                    sparseArray3 = sparseArray10;
                    ACRA.log.w(ACRA.LOG_TAG, str, e2);
                    i2 = i + 1;
                    sparseArray10 = sparseArray3;
                    sparseArray11 = sparseArray2;
                    str2 = str;
                    sparseArray12 = sparseArray;
                    hashMap = hashMap;
                    length = length;
                    fields = fieldArr;
                } catch (IllegalAccessException e17) {
                    e3 = e17;
                    i = i2;
                    sparseArray = sparseArray12;
                    sparseArray2 = sparseArray11;
                    sparseArray3 = sparseArray10;
                    str = str2;
                    ACRA.log.w(ACRA.LOG_TAG, str, e3);
                    i2 = i + 1;
                    sparseArray10 = sparseArray3;
                    sparseArray11 = sparseArray2;
                    str2 = str;
                    sparseArray12 = sparseArray;
                    hashMap = hashMap;
                    length = length;
                    fields = fieldArr;
                }
            }
            i2 = i + 1;
            sparseArray10 = sparseArray3;
            sparseArray11 = sparseArray2;
            str2 = str;
            sparseArray12 = sparseArray;
            hashMap = hashMap;
            length = length;
            fields = fieldArr;
        }
        hashMap.put(PREFIX_HARDKEYBOARDHIDDEN, sparseArray4);
        hashMap.put(PREFIX_KEYBOARD, sparseArray5);
        hashMap.put(PREFIX_KEYBOARDHIDDEN, sparseArray6);
        hashMap.put(PREFIX_NAVIGATION, sparseArray7);
        hashMap.put(PREFIX_NAVIGATIONHIDDEN, sparseArray8);
        hashMap.put(PREFIX_ORIENTATION, sparseArray9);
        hashMap.put(PREFIX_SCREENLAYOUT, sparseArray10);
        hashMap.put(PREFIX_TOUCHSCREEN, sparseArray11);
        hashMap.put(PREFIX_UI_MODE, sparseArray12);
        return hashMap;
    }

    /* access modifiers changed from: package-private */
    @Override // org.acra.collector.Collector
    public Element collect(ReportField reportField, ReportBuilder reportBuilder) {
        int i = AnonymousClass1.$SwitchMap$org$acra$ReportField[reportField.ordinal()];
        if (i == 1) {
            return this.initialConfiguration;
        }
        if (i == 2) {
            return collectConfiguration(this.context);
        }
        throw new IllegalArgumentException();
    }
}
