package org.acra.collector;

import android.os.Build;
import android.os.Process;
import com.android.internal.util.Predicate;
import java.io.IOException;
import java.io.InputStream;
import java.util.ArrayList;
import java.util.Set;
import org.acra.ACRA;
import org.acra.ACRAConstants;
import org.acra.ReportField;
import org.acra.builder.ReportBuilder;
import org.acra.collections.ImmutableList;
import org.acra.config.ACRAConfiguration;
import org.acra.model.Element;
import org.acra.model.StringElement;
import org.acra.util.IOUtils;
import org.acra.util.PackageManagerWrapper;

/* access modifiers changed from: package-private */
public final class LogCatCollector extends Collector {
    private final ACRAConfiguration config;
    private final PackageManagerWrapper pm;

    /* renamed from: org.acra.collector.LogCatCollector$2  reason: invalid class name */
    static /* synthetic */ class AnonymousClass2 {
        static final /* synthetic */ int[] $SwitchMap$org$acra$ReportField;

        /* JADX WARNING: Can't wrap try/catch for region: R(6:0|1|2|3|4|(3:5|6|8)) */
        /* JADX WARNING: Failed to process nested try/catch */
        /* JADX WARNING: Missing exception handler attribute for start block: B:3:0x0012 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:5:0x001d */
        static {
            int[] iArr = new int[ReportField.values().length];
            $SwitchMap$org$acra$ReportField = iArr;
            iArr[ReportField.LOGCAT.ordinal()] = 1;
            $SwitchMap$org$acra$ReportField[ReportField.EVENTSLOG.ordinal()] = 2;
            try {
                $SwitchMap$org$acra$ReportField[ReportField.RADIOLOG.ordinal()] = 3;
            } catch (NoSuchFieldError unused) {
            }
        }
    }

    LogCatCollector(ACRAConfiguration aCRAConfiguration, PackageManagerWrapper packageManagerWrapper) {
        super(ReportField.LOGCAT, ReportField.EVENTSLOG, ReportField.RADIOLOG);
        this.config = aCRAConfiguration;
        this.pm = packageManagerWrapper;
    }

    private Element collectLogCat(String str) {
        final String str2;
        int myPid = Process.myPid();
        if (!this.config.logcatFilterByPid() || myPid <= 0) {
            str2 = null;
        } else {
            str2 = Integer.toString(myPid) + "):";
        }
        ArrayList arrayList = new ArrayList();
        arrayList.add("logcat");
        if (str != null) {
            arrayList.add("-b");
            arrayList.add(str);
        }
        ImmutableList<String> logcatArguments = this.config.logcatArguments();
        int indexOf = logcatArguments.indexOf("-t");
        int i = -1;
        if (indexOf > -1 && indexOf < logcatArguments.size()) {
            i = Integer.parseInt(logcatArguments.get(indexOf + 1));
        }
        arrayList.addAll(logcatArguments);
        try {
            Process start = new ProcessBuilder(new String[0]).command(arrayList).redirectErrorStream(true).start();
            if (ACRA.DEV_LOGGING) {
                ACRA.log.d(ACRA.LOG_TAG, "Retrieving logcat output...");
            }
            StringElement stringElement = new StringElement(streamToString(start.getInputStream(), new Predicate<String>() {
                /* class org.acra.collector.LogCatCollector.AnonymousClass1 */

                public boolean apply(String str) {
                    String str2 = str2;
                    return str2 == null || str.contains(str2);
                }
            }, i));
            start.destroy();
            return stringElement;
        } catch (IOException e2) {
            ACRA.log.e(ACRA.LOG_TAG, "LogCatCollector.collectLogCat could not retrieve data.", e2);
            return ACRAConstants.NOT_AVAILABLE;
        }
    }

    private String streamToString(InputStream inputStream, Predicate<String> predicate, int i) {
        if (this.config.nonBlockingReadForLogcat()) {
            return IOUtils.streamToStringNonBlockingRead(inputStream, predicate, i);
        }
        return IOUtils.streamToString(inputStream, predicate, i);
    }

    /* access modifiers changed from: package-private */
    @Override // org.acra.collector.Collector
    public Element collect(ReportField reportField, ReportBuilder reportBuilder) {
        int i = AnonymousClass2.$SwitchMap$org$acra$ReportField[reportField.ordinal()];
        String str = null;
        if (i != 1) {
            if (i == 2) {
                str = "events";
            } else if (i == 3) {
                str = "radio";
            }
        }
        return collectLogCat(str);
    }

    /* access modifiers changed from: package-private */
    @Override // org.acra.collector.Collector
    public boolean shouldCollect(Set<ReportField> set, ReportField reportField, ReportBuilder reportBuilder) {
        return super.shouldCollect(set, reportField, reportBuilder) && (this.pm.hasPermission("android.permission.READ_LOGS") || Build.VERSION.SDK_INT >= 16);
    }
}
