package org.acra.collector;

import android.content.Context;
import android.os.Build;
import android.os.Environment;
import java.lang.reflect.Field;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;
import java.util.Arrays;
import java.util.Collection;
import org.acra.ACRA;
import org.acra.ACRAConstants;
import org.acra.ReportField;
import org.acra.builder.ReportBuilder;
import org.acra.config.ACRAConfiguration;
import org.acra.model.ComplexElement;
import org.acra.model.Element;
import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

/* access modifiers changed from: package-private */
public final class ReflectionCollector extends Collector {
    private final ACRAConfiguration config;
    private final Context context;

    /* renamed from: org.acra.collector.ReflectionCollector$1  reason: invalid class name */
    static /* synthetic */ class AnonymousClass1 {
        static final /* synthetic */ int[] $SwitchMap$org$acra$ReportField;

        /* JADX WARNING: Can't wrap try/catch for region: R(6:0|1|2|3|4|(3:5|6|8)) */
        /* JADX WARNING: Failed to process nested try/catch */
        /* JADX WARNING: Missing exception handler attribute for start block: B:3:0x0012 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:5:0x001d */
        static {
            int[] iArr = new int[ReportField.values().length];
            $SwitchMap$org$acra$ReportField = iArr;
            iArr[ReportField.BUILD.ordinal()] = 1;
            $SwitchMap$org$acra$ReportField[ReportField.BUILD_CONFIG.ordinal()] = 2;
            try {
                $SwitchMap$org$acra$ReportField[ReportField.ENVIRONMENT.ordinal()] = 3;
            } catch (NoSuchFieldError unused) {
            }
        }
    }

    ReflectionCollector(Context context2, ACRAConfiguration aCRAConfiguration) {
        super(ReportField.BUILD, ReportField.BUILD_CONFIG, ReportField.ENVIRONMENT);
        this.context = context2;
        this.config = aCRAConfiguration;
    }

    private static void collectConstants(Class<?> cls, JSONObject jSONObject) {
        Field[] fields = cls.getFields();
        for (Field field : fields) {
            try {
                Object obj = field.get(null);
                if (obj != null) {
                    if (field.getType().isArray()) {
                        jSONObject.put(field.getName(), new JSONArray((Collection) Arrays.asList((Object[]) obj)));
                    } else {
                        jSONObject.put(field.getName(), obj);
                    }
                }
            } catch (IllegalAccessException | IllegalArgumentException unused) {
            }
        }
    }

    private static void collectStaticGettersResults(Class<?> cls, JSONObject jSONObject) {
        Method[] methods = cls.getMethods();
        for (Method method : methods) {
            if (method.getParameterTypes().length == 0 && ((method.getName().startsWith("get") || method.getName().startsWith("is")) && !"getClass".equals(method.getName()))) {
                try {
                    jSONObject.put(method.getName(), method.invoke(null, null));
                } catch (IllegalAccessException | IllegalArgumentException | InvocationTargetException unused) {
                }
            }
        }
    }

    private Class<?> getBuildConfigClass() {
        Class<?> buildConfigClass = this.config.buildConfigClass();
        if (!buildConfigClass.equals(Object.class)) {
            return buildConfigClass;
        }
        String str = this.context.getPackageName() + ".BuildConfig";
        try {
            return Class.forName(str);
        } catch (ClassNotFoundException e2) {
            ACRA.log.e(ACRA.LOG_TAG, "Not adding buildConfig to log. Class Not found : " + str + ". Please configure 'buildConfigClass' in your ACRA config");
            throw e2;
        }
    }

    /* access modifiers changed from: package-private */
    @Override // org.acra.collector.Collector
    public Element collect(ReportField reportField, ReportBuilder reportBuilder) {
        ComplexElement complexElement = new ComplexElement();
        try {
            int i = AnonymousClass1.$SwitchMap$org$acra$ReportField[reportField.ordinal()];
            if (i == 1) {
                collectConstants(Build.class, complexElement);
                JSONObject jSONObject = new JSONObject();
                collectConstants(Build.VERSION.class, jSONObject);
                complexElement.put("VERSION", jSONObject);
            } else if (i == 2) {
                try {
                    collectConstants(getBuildConfigClass(), complexElement);
                } catch (ClassNotFoundException unused) {
                }
            } else if (i == 3) {
                collectStaticGettersResults(Environment.class, complexElement);
            } else {
                throw new IllegalArgumentException();
            }
            return complexElement;
        } catch (JSONException e2) {
            ACRA.log.w("Couldn't collect constants", e2);
            return ACRAConstants.NOT_AVAILABLE;
        }
    }
}
