package org.acra.collector;

import android.content.Context;
import android.os.Build;
import android.provider.Settings;
import java.lang.reflect.Field;
import java.util.Iterator;
import org.acra.ACRA;
import org.acra.ACRAConstants;
import org.acra.ReportField;
import org.acra.builder.ReportBuilder;
import org.acra.config.ACRAConfiguration;
import org.acra.model.ComplexElement;
import org.acra.model.Element;
import org.json.JSONException;

/* access modifiers changed from: package-private */
public final class SettingsCollector extends Collector {
    private static final String ERROR = "Error: ";
    private final ACRAConfiguration config;
    private final Context context;

    /* renamed from: org.acra.collector.SettingsCollector$1  reason: invalid class name */
    static /* synthetic */ class AnonymousClass1 {
        static final /* synthetic */ int[] $SwitchMap$org$acra$ReportField;

        /* JADX WARNING: Can't wrap try/catch for region: R(6:0|1|2|3|4|(3:5|6|8)) */
        /* JADX WARNING: Failed to process nested try/catch */
        /* JADX WARNING: Missing exception handler attribute for start block: B:3:0x0012 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:5:0x001d */
        static {
            int[] iArr = new int[ReportField.values().length];
            $SwitchMap$org$acra$ReportField = iArr;
            iArr[ReportField.SETTINGS_SYSTEM.ordinal()] = 1;
            $SwitchMap$org$acra$ReportField[ReportField.SETTINGS_SECURE.ordinal()] = 2;
            try {
                $SwitchMap$org$acra$ReportField[ReportField.SETTINGS_GLOBAL.ordinal()] = 3;
            } catch (NoSuchFieldError unused) {
            }
        }
    }

    SettingsCollector(Context context2, ACRAConfiguration aCRAConfiguration) {
        super(ReportField.SETTINGS_SYSTEM, ReportField.SETTINGS_SECURE, ReportField.SETTINGS_GLOBAL);
        this.context = context2;
        this.config = aCRAConfiguration;
    }

    private Element collectGlobalSettings() {
        if (Build.VERSION.SDK_INT < 17) {
            return ACRAConstants.NOT_AVAILABLE;
        }
        ComplexElement complexElement = new ComplexElement();
        Field[] fields = Settings.Global.class.getFields();
        for (Field field : fields) {
            if (!field.isAnnotationPresent(Deprecated.class) && field.getType() == String.class && isAuthorized(field)) {
                try {
                    String string = Settings.Global.getString(this.context.getContentResolver(), (String) field.get(null));
                    if (string != null) {
                        complexElement.put(field.getName(), string);
                    }
                } catch (IllegalArgumentException e2) {
                    ACRA.log.w(ACRA.LOG_TAG, ERROR, e2);
                } catch (SecurityException e3) {
                    ACRA.log.w(ACRA.LOG_TAG, ERROR, e3);
                } catch (IllegalAccessException e4) {
                    ACRA.log.w(ACRA.LOG_TAG, ERROR, e4);
                }
            }
        }
        return complexElement;
    }

    private Element collectSecureSettings() {
        ComplexElement complexElement = new ComplexElement();
        Field[] fields = Settings.Secure.class.getFields();
        for (Field field : fields) {
            if (!field.isAnnotationPresent(Deprecated.class) && field.getType() == String.class && isAuthorized(field)) {
                try {
                    String string = Settings.Secure.getString(this.context.getContentResolver(), (String) field.get(null));
                    if (string != null) {
                        complexElement.put(field.getName(), string);
                    }
                } catch (IllegalArgumentException e2) {
                    ACRA.log.w(ACRA.LOG_TAG, ERROR, e2);
                } catch (IllegalAccessException e3) {
                    ACRA.log.w(ACRA.LOG_TAG, ERROR, e3);
                }
            }
        }
        return complexElement;
    }

    private Element collectSystemSettings() {
        ComplexElement complexElement = new ComplexElement();
        Field[] fields = Settings.System.class.getFields();
        for (Field field : fields) {
            if (!field.isAnnotationPresent(Deprecated.class) && field.getType() == String.class) {
                try {
                    String string = Settings.System.getString(this.context.getContentResolver(), (String) field.get(null));
                    if (string != null) {
                        complexElement.put(field.getName(), string);
                    }
                } catch (IllegalArgumentException e2) {
                    ACRA.log.w(ACRA.LOG_TAG, ERROR, e2);
                } catch (IllegalAccessException e3) {
                    ACRA.log.w(ACRA.LOG_TAG, ERROR, e3);
                }
            }
        }
        return complexElement;
    }

    private boolean isAuthorized(Field field) {
        if (field == null || field.getName().startsWith("WIFI_AP")) {
            return false;
        }
        Iterator<String> it = this.config.excludeMatchingSettingsKeys().iterator();
        while (it.hasNext()) {
            if (field.getName().matches(it.next())) {
                return false;
            }
        }
        return true;
    }

    /* access modifiers changed from: package-private */
    @Override // org.acra.collector.Collector
    public Element collect(ReportField reportField, ReportBuilder reportBuilder) {
        try {
            int i = AnonymousClass1.$SwitchMap$org$acra$ReportField[reportField.ordinal()];
            if (i == 1) {
                return collectSystemSettings();
            }
            if (i == 2) {
                return collectSecureSettings();
            }
            if (i == 3) {
                return collectGlobalSettings();
            }
            throw new IllegalArgumentException();
        } catch (JSONException e2) {
            ACRA.log.w("Could not collect Settings", e2);
            return ACRAConstants.NOT_AVAILABLE;
        }
    }
}
