package org.acra.security;

import android.content.Context;
import java.security.KeyStore;
import org.acra.ACRA;
import org.acra.config.ACRAConfiguration;

public final class KeyStoreHelper {
    private static final String ASSET_PREFIX = "asset://";

    private KeyStoreHelper() {
    }

    /* JADX WARNING: Removed duplicated region for block: B:19:? A[RETURN, SYNTHETIC] */
    /* JADX WARNING: Removed duplicated region for block: B:9:0x0025  */
    public static KeyStore getKeyStore(Context context, ACRAConfiguration aCRAConfiguration) {
        KeyStore keyStore;
        try {
            keyStore = ((KeyStoreFactory) aCRAConfiguration.keyStoreFactoryClass().newInstance()).create(context);
        } catch (InstantiationException e2) {
            ACRA.log.e(ACRA.LOG_TAG, "Could not get keystore from factory", e2);
        } catch (IllegalAccessException e3) {
            ACRA.log.e(ACRA.LOG_TAG, "Could not get keystore from factory", e3);
        }
        if (keyStore == null) {
            return keyStore;
        }
        int resCertificate = aCRAConfiguration.resCertificate();
        String certificatePath = aCRAConfiguration.certificatePath();
        String certificateType = aCRAConfiguration.certificateType();
        if (resCertificate != 0) {
            return new ResourceKeyStoreFactory(certificateType, resCertificate).create(context);
        }
        if (certificatePath.equals("")) {
            return keyStore;
        }
        if (certificatePath.startsWith(ASSET_PREFIX)) {
            return new AssetKeyStoreFactory(certificateType, certificatePath.substring(8)).create(context);
        }
        return new FileKeyStoreFactory(certificateType, certificatePath).create(context);
        keyStore = null;
        if (keyStore == null) {
        }
    }
}
