package org.acra.sender;

import android.content.Context;
import android.net.Uri;
import android.text.TextUtils;
import java.io.IOException;
import java.net.URL;
import java.util.HashMap;
import java.util.Map;
import org.acra.ACRA;
import org.acra.ACRAConstants;
import org.acra.ReportField;
import org.acra.collections.ImmutableSet;
import org.acra.collector.CrashReportData;
import org.acra.config.ACRAConfiguration;
import org.acra.log.ACRALog;
import org.acra.model.Element;
import org.acra.util.HttpRequest;

public class HttpSender implements ReportSender {
    private final ACRAConfiguration config;
    private final Uri mFormUri;
    private final Map<ReportField, String> mMapping;
    private final Method mMethod;
    private String mPassword;
    private final Type mType;
    private String mUsername;

    /* renamed from: org.acra.sender.HttpSender$1  reason: invalid class name */
    static /* synthetic */ class AnonymousClass1 {
        static final /* synthetic */ int[] $SwitchMap$org$acra$sender$HttpSender$Method;
        static final /* synthetic */ int[] $SwitchMap$org$acra$sender$HttpSender$Type;

        /* JADX WARNING: Failed to process nested try/catch */
        /* JADX WARNING: Missing exception handler attribute for start block: B:11:0x002e */
        static {
            int[] iArr = new int[Method.values().length];
            $SwitchMap$org$acra$sender$HttpSender$Method = iArr;
            try {
                iArr[Method.POST.ordinal()] = 1;
            } catch (NoSuchFieldError unused) {
            }
            try {
                $SwitchMap$org$acra$sender$HttpSender$Method[Method.PUT.ordinal()] = 2;
            } catch (NoSuchFieldError unused2) {
            }
            int[] iArr2 = new int[Type.values().length];
            $SwitchMap$org$acra$sender$HttpSender$Type = iArr2;
            iArr2[Type.JSON.ordinal()] = 1;
            try {
                $SwitchMap$org$acra$sender$HttpSender$Type[Type.FORM.ordinal()] = 2;
            } catch (NoSuchFieldError unused3) {
            }
        }
    }

    public enum Method {
        POST,
        PUT
    }

    public enum Type {
        FORM {
            @Override // org.acra.sender.HttpSender.Type
            public String getContentType() {
                return "application/x-www-form-urlencoded";
            }
        },
        JSON {
            @Override // org.acra.sender.HttpSender.Type
            public String getContentType() {
                return "application/json";
            }
        };

        public abstract String getContentType();

        /* synthetic */ Type(AnonymousClass1 r3) {
            this();
        }
    }

    public HttpSender(ACRAConfiguration aCRAConfiguration, Method method, Type type, Map<ReportField, String> map) {
        this(aCRAConfiguration, method, type, null, map);
    }

    private boolean isNull(String str) {
        return str == null || ACRAConstants.NULL_VALUE.equals(str);
    }

    private Map<String, String> remap(Map<ReportField, Element> map) {
        ImmutableSet<ReportField> reportFields = this.config.getReportFields();
        if (reportFields.isEmpty()) {
            reportFields = new ImmutableSet<>(ACRAConstants.DEFAULT_REPORT_FIELDS);
        }
        HashMap hashMap = new HashMap(map.size());
        for (ReportField reportField : reportFields) {
            String join = TextUtils.join("\n", map.get(reportField).flatten());
            Map<ReportField, String> map2 = this.mMapping;
            if (map2 == null || map2.get(reportField) == null) {
                hashMap.put(reportField.toString(), join);
            } else {
                hashMap.put(this.mMapping.get(reportField), join);
            }
        }
        return hashMap;
    }

    @Override // org.acra.sender.ReportSender
    public void send(Context context, CrashReportData crashReportData) {
        String str;
        URL url;
        try {
            URL url2 = this.mFormUri == null ? new URL(this.config.formUri()) : new URL(this.mFormUri.toString());
            if (ACRA.DEV_LOGGING) {
                ACRALog aCRALog = ACRA.log;
                String str2 = ACRA.LOG_TAG;
                aCRALog.d(str2, "Connect to " + url2.toString());
            }
            String str3 = this.mUsername;
            String str4 = null;
            if (str3 == null) {
                str3 = isNull(this.config.formUriBasicAuthLogin()) ? null : this.config.formUriBasicAuthLogin();
            }
            String str5 = this.mPassword;
            if (str5 != null) {
                str4 = str5;
            } else if (!isNull(this.config.formUriBasicAuthPassword())) {
                str4 = this.config.formUriBasicAuthPassword();
            }
            HttpRequest httpRequest = new HttpRequest(this.config);
            httpRequest.setConnectionTimeOut(this.config.connectionTimeout());
            httpRequest.setSocketTimeOut(this.config.socketTimeout());
            httpRequest.setLogin(str3);
            httpRequest.setPassword(str4);
            httpRequest.setHeaders(this.config.getHttpHeaders());
            if (AnonymousClass1.$SwitchMap$org$acra$sender$HttpSender$Type[this.mType.ordinal()] != 1) {
                str = HttpRequest.getParamsAsFormString(remap(crashReportData));
            } else {
                str = crashReportData.toJSON().toString();
            }
            int i = AnonymousClass1.$SwitchMap$org$acra$sender$HttpSender$Method[this.mMethod.ordinal()];
            if (i == 1) {
                url = url2;
            } else if (i == 2) {
                url = new URL(url2.toString() + '/' + crashReportData.getProperty(ReportField.REPORT_ID));
            } else {
                throw new UnsupportedOperationException("Unknown method: " + this.mMethod.name());
            }
            httpRequest.send(context, url, this.mMethod, str, this.mType);
        } catch (IOException e2) {
            throw new ReportSenderException("Error while sending " + this.config.reportType() + " report via Http " + this.mMethod.name(), e2);
        }
    }

    public void setBasicAuth(String str, String str2) {
        this.mUsername = str;
        this.mPassword = str2;
    }

    public HttpSender(ACRAConfiguration aCRAConfiguration, Method method, Type type, String str, Map<ReportField, String> map) {
        Uri uri;
        this.config = aCRAConfiguration;
        this.mMethod = method;
        if (str == null) {
            uri = null;
        } else {
            uri = Uri.parse(str);
        }
        this.mFormUri = uri;
        this.mMapping = map;
        this.mType = type;
        this.mUsername = null;
        this.mPassword = null;
    }
}
